@@ -1,5 +1,5 @@
 package HTML::MobileJp::Filter::EntityReference;
-use Moose;
+use Any::Moose;
 
 with 'HTML::MobileJp::Filter::Role';
 
@@ -33,6 +33,8 @@ sub filter {
     $content;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 __END__
 
