@@ -1,5 +1,5 @@
 package HTML::MobileJp::Filter::PictogramFallback;
-use Moose;
+use Any::Moose;
 
 with 'HTML::MobileJp::Filter::Role';
 
@@ -53,6 +53,8 @@ sub fallback_name_htmlescape {
     $fallback;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 __END__
 
